require 'sinatra/base'
require 'haml'
require 'rack/jquery'
require 'rack/jquery_ui'

class App < Sinatra::Base

  enable :inline_templates
  use Rack::JQuery
  use Rack::JQueryUI

  %w{google media_temple microsoft cloudflare unspecified}.each do |name|

    get "/#{name}-cdn" do
      haml :accordion, :layout => name.to_sym
    end
  end

  get "/" do
    haml :index, :layout => :unspecified
  end

  get "/fallback-only" do
    haml :accordion, :layout => :fallback
  end

  get "/ui/:plugin" do |plugin|
    haml plugin.to_sym, :layout => :ui
  end
end

class AppWithDefaults < Sinatra::Base

  enable :inline_templates
  use Rack::JQuery
  use Rack::JQueryUI, :organisation => :cloudflare 

  %w{google media_temple microsoft cloudflare unspecified}.each do |name|

    get "/#{name}-cdn" do
      haml :accordion, :layout => name.to_sym
    end
  end

  get "/" do
    haml :index, :layout => :unspecified
  end

  get "/fallback-only" do
    haml :accordion, :layout => :fallback
  end

  get "/ui/:plugin" do |plugin|
    haml plugin.to_sym, :layout => :ui
  end

end

__END__

@@google
%html
  %head
    = Rack::JQuery.cdn( env, :organisation => :google )
    = Rack::JQueryUI.cdn( env, :organisation => :google )
    %link{ href: "http://code.jquery.com/ui/#{Rack::JQueryUI::JQUERY_UI_VERSION}/themes/smoothness/jquery-ui.css", rel: "stylesheet"}
    :css
      body {
        font-family: "Trebuchet MS", "Helvetica", "Arial",  "Verdana", "sans-serif";
        font-size: 62.5%;
      }
  = yield

@@microsoft
%html
  %head
    = Rack::JQuery.cdn( env, :organisation => :microsoft )
    = Rack::JQueryUI.cdn( env, :organisation => :microsoft )
    %link{ href: "http://code.jquery.com/ui/#{Rack::JQueryUI::JQUERY_UI_VERSION}/themes/smoothness/jquery-ui.css", rel: "stylesheet"}
    :css
      body {
        font-family: "Trebuchet MS", "Helvetica", "Arial",  "Verdana", "sans-serif";
        font-size: 62.5%;
      }
  = yield

@@cloudflare
%html
  %head
    = Rack::JQuery.cdn( env, :organisation => :cloudflare )
    = Rack::JQueryUI.cdn( env, :organisation => :cloudflare )
    %link{ href: "http://code.jquery.com/ui/#{Rack::JQueryUI::JQUERY_UI_VERSION}/themes/smoothness/jquery-ui.css", rel: "stylesheet"}
    :css
      body {
        font-family: "Trebuchet MS", "Helvetica", "Arial",  "Verdana", "sans-serif";
        font-size: 62.5%;
      }
  = yield

@@media_temple
%html
  %head
    = Rack::JQuery.cdn( env, :organisation => :media_temple )
    = Rack::JQueryUI.cdn( env, :organisation => :media_temple )
    %link{ href: "http://code.jquery.com/ui/#{Rack::JQueryUI::JQUERY_UI_VERSION}/themes/smoothness/jquery-ui.css", rel: "stylesheet"}
    :css
      body {
        font-family: "Trebuchet MS", "Helvetica", "Arial",  "Verdana", "sans-serif";
        font-size: 62.5%;
      }
  = yield

@@unspecified
%html
  %head
    = Rack::JQuery.cdn(env)
    = Rack::JQueryUI.cdn(env)
    %link{ href: "http://code.jquery.com/ui/#{Rack::JQueryUI::JQUERY_UI_VERSION}/themes/smoothness/jquery-ui.css", rel: "stylesheet"}
    :css
      body {
        font-family: "Trebuchet MS", "Helvetica", "Arial",  "Verdana", "sans-serif";
        font-size: 62.5%;
      }
  %body
    = yield

@@fallback
%html
  %head
    = Rack::JQuery.cdn env
    = Rack::JQueryUI.cdn( env, :organisation => false )
    %link{ href: "http://code.jquery.com/ui/#{Rack::JQueryUI::JQUERY_UI_VERSION}/themes/smoothness/jquery-ui.css", rel: "stylesheet"}
    :css
      body {
        font-family: "Trebuchet MS", "Helvetica", "Arial",  "Verdana", "sans-serif";
        font-size: 62.5%;
      }
  = yield

@@ui
%html
  %head
    = Rack::JQuery.cdn(env)
    = Rack::JQueryUI.cdn(env)
    %link{ href: "http://code.jquery.com/ui/#{Rack::JQueryUI::JQUERY_UI_VERSION}/themes/smoothness/jquery-ui.css", rel: "stylesheet"}
    :css
      body {
        font-family: "Trebuchet MS", "Helvetica", "Arial",  "Verdana", "sans-serif";
        font-size: 62.5%;
      }
  %body
    = yield

@@index
%p
  %a{ href: "/google-cdn" }
    google-cdn
%p
  %a{ href: "/media-temple-cdn" }
    media-temple
%p
  %a{ href: "/microsoft-cdn" }
    microsoft-cdn
%p
  %a{ href: "/cloudflare-cdn" }
    cloudflare-cdn
%p
  %a{ href: "/unspecified-cdn" }
    unspecified-cdn
%p
  %a{ href: "/fallback-only" }
    forced fallback
%p
  %a{ href: "/ui/accordion" }
    accordion

@@accordion
:javascript
  $(function() {
    $( "#accordion" ).accordion();
  });
#accordion
  %h3
    Section 1
  %div
    %p
      Mauris mauris ante, blandit et, ultrices a, suscipit eget, quam. Integer
      ut neque. Vivamus nisi metus, molestie vel, gravida in, condimentum sit
      amet, nunc. Nam a nibh. Donec suscipit eros. Nam mi. Proin viverra leo ut
      odio. Curabitur malesuada. Vestibulum a velit eu ante scelerisque vulputate.
  %h3
    Section 2
  %div
    %p
      Sed non urna. Donec et ante. Phasellus eu ligula. Vestibulum sit amet
      purus. Vivamus hendrerit, dolor at aliquet laoreet, mauris turpis porttitor
      velit, faucibus interdum tellus libero ac justo. Vivamus non quam. In
      suscipit faucibus urna.
  %h3
    Section 3
  %div
    %p
      Nam enim risus, molestie et, porta ac, aliquam ac, risus. Quisque lobortis.
      Phasellus pellentesque purus in massa. Aenean in pede. Phasellus ac libero
      ac tellus pellentesque semper. Sed ac felis. Sed commodo, magna quis
      lacinia ornare, quam ante aliquam nisi, eu iaculis leo purus venenatis dui.
    %ul
      %li
        List item one
      %li
        List item two
      %li
        List item three
  %h3
    Section 4
  %div
    %p
      Cras dictum. Pellentesque habitant morbi tristique senectus et netus
      et malesuada fames ac turpis egestas. Vestibulum ante ipsum primis in
      faucibus orci luctus et ultrices posuere cubilia Curae; Aenean lacinia
      mauris vel est.
    %p
      Suspendisse eu nisl. Nullam ut libero. Integer dignissim consequat lectus.
      Class aptent taciti sociosqu ad litora torquent per conubia nostra, per
      inceptos himenaeos.